.. _documentation-guide:

===================
Documentation Guide
===================

**Contents**

.. toctree::
   :maxdepth: 2

   getting-started.rst
   doc-workflow.rst
   doc-tools.rst
   doc-future-index.rst
   doc-issues-hub.md

Documentation helps guide new users, fosters communication between developers,
and shares tips and best practices with other community members. That's why
the Jupyter project is focused on documenting new features and to keeping
the documentation up-to-date.
